<TS language="sk" version="2.0">
<context>
    <name>AboutDialog</name>
    <message>
        <source>About Gridcoin</source>
        <translation>O Gridcoine</translation>
    </message>
    </context>
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Create a new address</source>
        <translation>Vytvoriť novú adresu</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Nový</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>Zkopírovať práve zvolenú adresu</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Kopírovať</translation>
    </message>
    <message>
        <source>Show &amp;QR Code</source>
        <translation>Zobraziť &amp;QR kód</translation>
    </message>
    <message>
        <source>Sign a message to prove you own a Gridcoin address</source>
        <translation>Podpísať správu ako dôkaz, že vlastníte túto Gridcoin adresu</translation>
    </message>
    <message>
        <source>Sign &amp;Message</source>
        <translation>&amp;Podpísať správu</translation>
    </message>
    <message>
        <source>Verify a message to ensure it was signed with a specified Gridcoin address</source>
        <translation>Skontrolovať podpis správy, aby ste sa uistili, že bola podpísaná s určitou Gridcoin adresou</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>Vymaž vybranú adresu zo zoznamu</translation>
    </message>
    <message>
        <source>Address Book</source>
        <translation>Adresár</translation>
    </message>
    <message>
        <source>These are your Gridcoin addresses for receiving payments. You may want to give a different one to each sender so you can keep track of who is paying you.</source>
        <translation>Na naslednovné adresy môžte prijať Gridcoin platby. Pre každú očakávanú platbu si môžte vytvoriť novú adresu, aby ste vedeli kto a za čo vám platí.</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Zmazať</translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation>Kopírovať &amp;Popis</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Upraviť</translation>
    </message>
    <message>
        <source>Export Address Book Data</source>
        <translation>Exportovať dáta z adresára</translation>
    </message>
    <message>
        <source>Error exporting</source>
        <translation>Chyba pri exporte</translation>
    </message>
    <message>
        <source>Could not write to file %1.</source>
        <translation>Zlyhal zapís do súboru %1.</translation>
    </message>
</context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation>Názov</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Adresa</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(bez popisu)</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Passphrase Dialog</source>
        <translation>Dialóg hesla</translation>
    </message>
    <message>
        <source>Enter passphrase</source>
        <translation>Zadajte heslo</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>Nové heslo</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>Zopakujte nové heslo</translation>
    </message>
    <message>
        <source>For staking only</source>
        <translation>Len pre stávkovanie</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation>Zmena hesla</translation>
    </message>
    <message>
        <source>The supplied passphrases do not match.</source>
        <translation>Zadané heslá nesúhlasia.</translation>
    </message>
    <message>
        <source>Warning: The Caps Lock key is on!</source>
        <translation>Upozornenie: Máte zapnutý Caps Lock!</translation>
    </message>
</context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>Wallet</source>
        <translation>Peňaženka</translation>
    </message>
    <message>
        <source>&amp;Overview</source>
        <translation>&amp;Prehľad</translation>
    </message>
    <message>
        <source>Show general overview of wallet</source>
        <translation>Zobraziť celkový prehľad o peňaženke</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation>&amp;Odoslať</translation>
    </message>
    <message>
        <source>&amp;Receive</source>
        <translation>&amp;Prijať</translation>
    </message>
    <message>
        <source>Browse transaction history</source>
        <translation>Prechádzať históriu transakcií</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>U&amp;končiť</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation>Ukončiť program</translation>
    </message>
    <message>
        <source>&amp;Options...</source>
        <translation>&amp;Možnosti...</translation>
    </message>
    <message>
        <source>&amp;Show / Hide</source>
        <translation>Zobraziť / skryť</translation>
    </message>
    <message>
        <source>&amp;Encrypt Wallet...</source>
        <translation>&amp;Zašifrovať Peňaženku...</translation>
    </message>
    <message>
        <source>&amp;Change Passphrase...</source>
        <translation>&amp;Zmena Hesla...</translation>
    </message>
    <message>
        <source>Change the passphrase used for wallet encryption</source>
        <translation>Zmeniť heslo použité na šifrovanie peňaženky</translation>
    </message>
    <message>
        <source>Sign &amp;message...</source>
        <translation>Podpísať &amp;správu...</translation>
    </message>
    <message>
        <source>&amp;Verify message...</source>
        <translation>O&amp;veriť správu...</translation>
    </message>
    <message>
        <source>&amp;Debug window</source>
        <translation>&amp;Okno pre ladenie</translation>
    </message>
    <message>
        <source>Open debugging and diagnostic console</source>
        <translation>Otvor konzolu pre ladenie a diagnostiku</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Súbor</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Nastavenia</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Pomoc</translation>
    </message>
    <message>
        <source>Gridcoin client</source>
        <translation>Gridcoin klient</translation>
    </message>
    <message numerus="yes">
        <source>%n active connection(s) to the Gridcoin network</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>Processed %n block(s) of transaction history.</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n second(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Up to date</source>
        <translation>Aktualizovaný</translation>
    </message>
    <message>
        <source>Catching up...</source>
        <translation>Sťahujem...</translation>
    </message>
    <message>
        <source>Last received block was generated %1.</source>
        <translation>Posledný prijatý blok bol vytvorený %1.</translation>
    </message>
    <message>
        <source>Sent transaction</source>
        <translation>Odoslané transakcie</translation>
    </message>
    <message>
        <source>Incoming transaction</source>
        <translation>Prijatá transakcia</translation>
    </message>
    <message>
        <source>URI handling</source>
        <translation>URI manipulácia</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;locked&lt;/b&gt;</source>
        <translation>Peňaženka je &lt;b&gt;zašifrovaná&lt;/b&gt; a momentálne &lt;b&gt;zamknutá&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Backup Failed</source>
        <translation>Zálohovanie zlyhalo</translation>
    </message>
    </context>
<context>
    <name>ClientModel</name>
    <message>
        <source>Network Alert</source>
        <translation>Výstraha siete</translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Quantity:</source>
        <translation>Množstvo:</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation>Bajtov:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Suma:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>Poplatok:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>Po poplatku:</translation>
    </message>
    <message>
        <source>Change:</source>
        <translation>Zmena:</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Suma</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Dátum</translation>
    </message>
    <message>
        <source>Confirmations</source>
        <translation>Potvrdenia</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Potvrdené</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Adresa</translation>
    </message>
    <message>
        <source>yes</source>
        <translation>áno</translation>
    </message>
    <message>
        <source>no</source>
        <translation>nie</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(bez popisu)</translation>
    </message>
    </context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>Edit Address</source>
        <translation>Upraviť adresu</translation>
    </message>
    <message>
        <source>&amp;Label</source>
        <translation>&amp;Popis</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation>&amp;Adresa</translation>
    </message>
    <message>
        <source>New sending address</source>
        <translation>Nová adresa pre odoslanie</translation>
    </message>
    <message>
        <source>The entered address "%1" is not a valid Gridcoin address.</source>
        <translation>Zadaná adresa "%1" nie je platnou Gridcoin adresou.</translation>
    </message>
    <message>
        <source>The entered address "%1" is already in the address book.</source>
        <translation>Zadaná adresa "%1" sa už nachádza v adresári.</translation>
    </message>
    </context>
<context>
    <name>GUIUtil::HelpMessageBox</name>
    <message>
        <source>version</source>
        <translation>verzia</translation>
    </message>
    <message>
        <source>Usage:</source>
        <translation>Použitie:</translation>
    </message>
    <message>
        <source>command-line options</source>
        <translation>možnosti príkazového riadka</translation>
    </message>
    </context>
<context>
    <name>Intro</name>
    <message numerus="yes">
        <source>%n GB of free space available</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(of %n GB needed)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(%n GB needed for full chain)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>Možnosti</translation>
    </message>
    <message>
        <source>&amp;Main</source>
        <translation>&amp;Hlavné</translation>
    </message>
    <message>
        <source>&amp;Network</source>
        <translation>&amp;Sieť</translation>
    </message>
    <message>
        <source>Map port using &amp;UPnP</source>
        <translation>Mapovať port pomocou &amp;UPnP</translation>
    </message>
    <message>
        <source>IP address of the proxy (e.g. 127.0.0.1)</source>
        <translation>IP adresa proxy servera (napr. 127.0.0.1)</translation>
    </message>
    <message>
        <source>Port of the proxy (e.g. 9050)</source>
        <translation>Port proxy (napr. 9050)</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Okno</translation>
    </message>
    <message>
        <source>Show only a tray icon after minimizing the window.</source>
        <translation>Zobraziť len ikonu na lište po minimalizovaní okna.</translation>
    </message>
    <message>
        <source>&amp;Minimize to the tray instead of the taskbar</source>
        <translation>Zobraziť len ikonu na lište po minimalizovaní okna.</translation>
    </message>
    <message>
        <source>M&amp;inimize on close</source>
        <translation>M&amp;inimalizovať pri zavretí</translation>
    </message>
    <message>
        <source>&amp;Display</source>
        <translation>&amp;Zobrazenie</translation>
    </message>
    <message>
        <source>User Interface &amp;language:</source>
        <translation>Jazyk užívateľského rozhrania:</translation>
    </message>
    <message>
        <source>&amp;Unit to show amounts in:</source>
        <translation>&amp;Zobrazovať hodnoty v jednotkách:</translation>
    </message>
    <message>
        <source>Choose the default subdivision unit to show in the interface and when sending coins.</source>
        <translation>Zvoľte ako deliť bitcoin pri zobrazovaní pri platbách a užívateľskom rozhraní.</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>Zrušiť</translation>
    </message>
    <message>
        <source>default</source>
        <translation>predvolené</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Upozornenie</translation>
    </message>
    <message>
        <source>This setting will take effect after restarting Gridcoin.</source>
        <translation>Toto nastavenie sa prejaví až po reštartovaní Gridcoin.</translation>
    </message>
    <message>
        <source>The supplied proxy address is invalid.</source>
        <translation>Zadaná proxy adresa je neplatná.</translation>
    </message>
    </context>
<context>
    <name>OverviewPage</name>
    <message>
        <source>Form</source>
        <translation>Forma</translation>
    </message>
    <message>
        <source>Available:</source>
        <translation>Disponibilné:</translation>
    </message>
    <message>
        <source>Your current spendable balance</source>
        <translation>Váš aktuálny disponibilný zostatok</translation>
    </message>
    <message>
        <source>Immature:</source>
        <translation>Nezrelé:</translation>
    </message>
    <message>
        <source>Total:</source>
        <translation>Celkovo:</translation>
    </message>
    <message>
        <source>Your current total balance</source>
        <translation>Váš súčasný celkový zostatok</translation>
    </message>
    </context>
<context>
    <name>QObject</name>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n year(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>QRCodeDialog</name>
    <message>
        <source>Message:</source>
        <translation>Správa:</translation>
    </message>
    <message>
        <source>Error encoding URI into QR Code.</source>
        <translation>Chyba kódovania URI do QR Code.</translation>
    </message>
    <message>
        <source>The entered amount is invalid, please check.</source>
        <translation>Zadaná suma je neplatná, prosím skontrolujte.</translation>
    </message>
    </context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>N/A</source>
        <translation>nie je k dispozícii</translation>
    </message>
    <message>
        <source>Client version</source>
        <translation>Verzia klienta</translation>
    </message>
    <message>
        <source>&amp;Information</source>
        <translation>&amp;Informácia</translation>
    </message>
    <message>
        <source>Startup time</source>
        <translation>Čas spustenia</translation>
    </message>
    <message>
        <source>Number of connections</source>
        <translation>Počet pripojení</translation>
    </message>
    <message>
        <source>Block chain</source>
        <translation>Reťazec blokov</translation>
    </message>
    <message>
        <source>Current number of blocks</source>
        <translation>Aktuálny počet blokov</translation>
    </message>
    <message>
        <source>Last block time</source>
        <translation>Čas posledného bloku</translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation>&amp;Otvoriť</translation>
    </message>
    <message>
        <source>&amp;Clear</source>
        <translation>&amp;Vyčistiť</translation>
    </message>
    <message>
        <source>&amp;Console</source>
        <translation>&amp;Konzola</translation>
    </message>
    <message>
        <source>&amp;Network Traffic</source>
        <translation>&amp;Sieťová prevádzka</translation>
    </message>
    <message>
        <source>Totals</source>
        <translation>Celkovo:</translation>
    </message>
    <message>
        <source>In:</source>
        <translation>Dnu:</translation>
    </message>
    <message>
        <source>Out:</source>
        <translation>Von:</translation>
    </message>
    <message>
        <source>Debug log file</source>
        <translation>Súbor záznamu ladenia</translation>
    </message>
    <message>
        <source>Clear console</source>
        <translation>Vymazať konzolu</translation>
    </message>
    <message>
        <source>Client name</source>
        <translation>Meno klienta</translation>
    </message>
    <message>
        <source>Use up and down arrows to navigate history, and &lt;b&gt;Ctrl-L&lt;/b&gt; to clear screen.</source>
        <translation>Použi šípky hore a dolu pre navigáciu históriou a &lt;b&gt;Ctrl-L&lt;/b&gt; pre vyčistenie obrazovky.</translation>
    </message>
    <message>
        <source>Type &lt;b&gt;help&lt;/b&gt; for an overview of available commands.</source>
        <translation>Napíš &lt;b&gt;help&lt;/b&gt; pre prehľad dostupných príkazov.</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Send Coins</source>
        <translation>Poslať Bitcoins</translation>
    </message>
    <message>
        <source>Inputs...</source>
        <translation>Vstupy...</translation>
    </message>
    <message>
        <source>automatically selected</source>
        <translation>automaticky vybrané</translation>
    </message>
    <message>
        <source>Insufficient funds!</source>
        <translation>Nedostatok prostriedkov!</translation>
    </message>
    <message>
        <source>Quantity:</source>
        <translation>Množstvo:</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation>Bajtov:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Suma:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>Poplatok:</translation>
    </message>
    <message>
        <source>no</source>
        <translation>nie</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>Po poplatku:</translation>
    </message>
    <message>
        <source>Send to multiple recipients at once</source>
        <translation>Poslať viacerým príjemcom naraz</translation>
    </message>
    <message>
        <source>Add &amp;Recipient</source>
        <translation>&amp;Pridať príjemcu</translation>
    </message>
    <message>
        <source>Clear &amp;All</source>
        <translation>&amp;Zmazať všetko</translation>
    </message>
    <message>
        <source>Confirm the send action</source>
        <translation>Potvrďte odoslanie</translation>
    </message>
    <message>
        <source>S&amp;end</source>
        <translation>&amp;Odoslať</translation>
    </message>
    <message>
        <source>&lt;b&gt;%1&lt;/b&gt; to %2 (%3)</source>
        <translation>&lt;b&gt;%1&lt;/b&gt; do %2 (%3)</translation>
    </message>
    <message>
        <source>The recipient address is not valid, please recheck.</source>
        <translation>Adresa príjemcu je neplatná, overte ju prosím.</translation>
    </message>
    <message>
        <source>The amount exceeds your balance.</source>
        <translation>Suma je vyššia ako Váš zostatok.</translation>
    </message>
    <message>
        <source>Error: Transaction creation failed.</source>
        <translation>Chyba: Vytvorenie transakcie zlyhalo.</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(bez popisu)</translation>
    </message>
    <message>
        <source>WARNING: Invalid Gridcoin address</source>
        <translation>UPOZORNENIE: Neplatná Gridcoin adresa</translation>
    </message>
    </context>
<context>
    <name>SendCoinsEntry</name>
    <message>
        <source>A&amp;mount:</source>
        <translation>Su&amp;ma:</translation>
    </message>
    <message>
        <source>Pay &amp;To:</source>
        <translation>Zapla&amp;tiť:</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation>Správa:</translation>
    </message>
    <message>
        <source>&amp;Label:</source>
        <translation>&amp;Popis:</translation>
    </message>
    <message>
        <source>Form</source>
        <translation>Formulár</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>Vložte adresu z klipbordu</translation>
    </message>
    <message>
        <source>Enter a label for this address to add it to your address book</source>
        <translation>Vložte popis pre túto adresu aby sa pridala do adresára</translation>
    </message>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    <message>
        <source>Signatures - Sign / Verify a Message</source>
        <translation>Podpisy - Podpísať / Overiť správu</translation>
    </message>
    <message>
        <source>&amp;Sign Message</source>
        <translation>&amp;Podpísať Správu</translation>
    </message>
    <message>
        <source>Choose an address from the address book</source>
        <translation>Vyberte adresu z adresára</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>Vložte adresu z klipbordu</translation>
    </message>
    <message>
        <source>Enter the message you want to sign here</source>
        <translation>Sem vložte správu ktorú chcete podpísať</translation>
    </message>
    <message>
        <source>Copy the current signature to the system clipboard</source>
        <translation>Kopírovať práve zvolenú adresu do systémového klipbordu</translation>
    </message>
    <message>
        <source>Sign &amp;Message</source>
        <translation>Podpísať &amp;správu</translation>
    </message>
    <message>
        <source>Reset all sign message fields</source>
        <translation>Vynulovať všetky polia podpisu správy</translation>
    </message>
    <message>
        <source>Clear &amp;All</source>
        <translation>&amp;Zmazať všetko</translation>
    </message>
    <message>
        <source>&amp;Verify Message</source>
        <translation>O&amp;veriť správu...</translation>
    </message>
    <message>
        <source>Reset all verify message fields</source>
        <translation>Obnoviť všetky polia v overiť správu</translation>
    </message>
    <message>
        <source>Enter Gridcoin signature</source>
        <translation>Zadajte Gridcoin podpis</translation>
    </message>
    <message>
        <source>The entered address is invalid.</source>
        <translation>Zadaná adresa je neplatná.</translation>
    </message>
    <message>
        <source>Please check the address and try again.</source>
        <translation>Prosím skontrolujte adresu a skúste znova.</translation>
    </message>
    <message>
        <source>Message signing failed.</source>
        <translation>Podpísanie správy zlyhalo.</translation>
    </message>
    <message>
        <source>Message signed.</source>
        <translation>Správa podpísaná.</translation>
    </message>
    <message>
        <source>Please check the signature and try again.</source>
        <translation>Prosím skontrolujte podpis a skúste znova.</translation>
    </message>
    <message>
        <source>The signature did not match the message digest.</source>
        <translation>Podpis nezodpovedá súhrnu správy.</translation>
    </message>
    <message>
        <source>Message verification failed.</source>
        <translation>Overenie správy zlyhalo.</translation>
    </message>
    <message>
        <source>Message verified.</source>
        <translation>Správa overená.</translation>
    </message>
</context>
<context>
    <name>TransactionDesc</name>
    <message numerus="yes">
        <source>Open for %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Open until %1</source>
        <translation>Otvorené do %1</translation>
    </message>
    <message>
        <source>conflicted</source>
        <translation>v rozpore</translation>
    </message>
    <message>
        <source>%1/unconfirmed</source>
        <translation>%1/nepotvrdené</translation>
    </message>
    <message>
        <source>%1 confirmations</source>
        <translation>%1 potvrdení</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Stav</translation>
    </message>
    <message>
        <source>, has not been successfully broadcast yet</source>
        <translation>, ešte nebola úspešne odoslaná</translation>
    </message>
    <message numerus="yes">
        <source>, broadcast through %n node(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Dátum</translation>
    </message>
    <message>
        <source>Source</source>
        <translation>Zdroj</translation>
    </message>
    <message>
        <source>From</source>
        <translation>Od</translation>
    </message>
    <message>
        <source>To</source>
        <translation>Pre</translation>
    </message>
    <message>
        <source>label</source>
        <translation>popis</translation>
    </message>
    <message numerus="yes">
        <source>matures in %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Message</source>
        <translation>Správa</translation>
    </message>
    <message>
        <source>Comment</source>
        <translation>Komentár</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Suma</translation>
    </message>
    <message>
        <source>true</source>
        <translation>pravda</translation>
    </message>
    <message>
        <source>false</source>
        <translation>nepravda</translation>
    </message>
</context>
<context>
    <name>TransactionDescDialog</name>
    <message>
        <source>Transaction details</source>
        <translation>Detaily transakcie</translation>
    </message>
    <message>
        <source>This pane shows a detailed description of the transaction</source>
        <translation>Táto časť obrazovky zobrazuje detailný popis transakcie</translation>
    </message>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Date</source>
        <translation>Dátum</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Typ</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Adresa</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Hodnota</translation>
    </message>
    <message numerus="yes">
        <source>Open for %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Open until %1</source>
        <translation>Otvorené do %1</translation>
    </message>
    <message>
        <source>Unconfirmed</source>
        <translation>Nepotvrdené</translation>
    </message>
    <message>
        <source>Confirmed (%1 confirmations)</source>
        <translation>Potvrdené (%1 potvrdení)</translation>
    </message>
    <message>
        <source>Conflicted</source>
        <translation>V rozpore</translation>
    </message>
    <message>
        <source>Received with</source>
        <translation>Prijaté s</translation>
    </message>
    <message>
        <source>Received from</source>
        <translation>Prijaté od:</translation>
    </message>
    <message>
        <source>Sent to</source>
        <translation>Odoslané na</translation>
    </message>
    <message>
        <source>Payment to yourself</source>
        <translation>Platba sebe samému</translation>
    </message>
    <message>
        <source>Amount removed from or added to balance.</source>
        <translation>Suma pridaná alebo odobraná k zostatku.</translation>
    </message>
</context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Today</source>
        <translation>Dnes</translation>
    </message>
    <message>
        <source>This month</source>
        <translation>Tento mesiac</translation>
    </message>
    <message>
        <source>Last month</source>
        <translation>Minulý mesiac</translation>
    </message>
    <message>
        <source>This year</source>
        <translation>Tento rok</translation>
    </message>
    <message>
        <source>Range...</source>
        <translation>Rozsah...</translation>
    </message>
    <message>
        <source>Received with</source>
        <translation>Prijaté s</translation>
    </message>
    <message>
        <source>Sent to</source>
        <translation>Odoslané na</translation>
    </message>
    <message>
        <source>To yourself</source>
        <translation>Samému sebe</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Iné</translation>
    </message>
    <message>
        <source>Min amount</source>
        <translation>Min. množstvo</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Potvrdené</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Dátum</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Typ</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Adresa</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Suma</translation>
    </message>
    <message>
        <source>Error exporting</source>
        <translation>Chyba pri exporte</translation>
    </message>
    <message>
        <source>Range:</source>
        <translation>Rozsah:</translation>
    </message>
    <message>
        <source>to</source>
        <translation>do</translation>
    </message>
</context>
<context>
    <name>WalletModel</name>
    <message>
        <source>Sending...</source>
        <translation>Posielam...</translation>
    </message>
</context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>Usage:</source>
        <translation>Použitie:</translation>
    </message>
    <message>
        <source>List commands</source>
        <translation>Zoznam príkazov</translation>
    </message>
    <message>
        <source>Failed to listen on any port. Use -listen=0 if you want this.</source>
        <translation>Chyba počúvania na ktoromkoľvek porte. Použi -listen=0 ak toto chcete.</translation>
    </message>
    <message>
        <source>Gridcoin version</source>
        <translation>Gridcoin verzia</translation>
    </message>
    <message>
        <source>Invalid amount for -paytxfee=&lt;amount&gt;: '%s'</source>
        <translation>Neplatná suma pre -paytxfee=&lt;amount&gt;: '%s'</translation>
    </message>
    <message>
        <source>Invalid amount for -mininput=&lt;amount&gt;: '%s'</source>
        <translation>Neplatná suma pre -mininput=&lt;amount&gt;: '%s'</translation>
    </message>
    <message>
        <source>Verifying database integrity...</source>
        <translation>Overenie integrity databázy ...</translation>
    </message>
    <message>
        <source>wallet.dat corrupt, salvage failed</source>
        <translation>wallet.dat je poškodený, záchrana zlyhala</translation>
    </message>
    <message>
        <source>Invalid -proxy address: '%s'</source>
        <translation>Neplatná adresa proxy: '%s'</translation>
    </message>
    <message>
        <source>Invalid -tor address: '%s'</source>
        <translation>Neplatná -tor adresa: '%s'</translation>
    </message>
    <message>
        <source>Invalid amount for -reservebalance=&lt;amount&gt;</source>
        <translation>Neplatná suma pre -reservebalance=&lt;množstvo&gt;</translation>
    </message>
    <message>
        <source>Loading addresses...</source>
        <translation>Načítavanie adries...</translation>
    </message>
    <message>
        <source>Sending...</source>
        <translation>Posielam...</translation>
    </message>
    <message>
        <source>Invalid amount</source>
        <translation>Neplatná suma</translation>
    </message>
    <message>
        <source>Warning: Disk space is low!</source>
        <translation>Upozornenie: Nedostatok miesta na disku!</translation>
    </message>
    <message>
        <source>Unknown network specified in -onlynet: '%s'</source>
        <translation>Neznáma sieť upresnená v -onlynet: '%s'</translation>
    </message>
    <message>
        <source>Insufficient funds</source>
        <translation>Nedostatok prostriedkov</translation>
    </message>
    <message>
        <source>Loading block index...</source>
        <translation>Načítavanie zoznamu blokov...</translation>
    </message>
    <message>
        <source>Loading wallet...</source>
        <translation>Načítavam peňaženku...</translation>
    </message>
    <message>
        <source>Cannot write default address</source>
        <translation>Nie je možné zapísať predvolenú adresu.</translation>
    </message>
    <message>
        <source>Rescanning...</source>
        <translation>Nové prehľadávanie...</translation>
    </message>
    <message>
        <source>Done loading</source>
        <translation>Dokončené načítavanie</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Chyba</translation>
    </message>
</context>
</TS>